==> ngraph-v0.27.0-rc.0.tar: ngraph-v0.27.0-rc.0/src/ngraph/op/atan2.hpp <==
//*****************************************************************************
// Copyright 2017-2019 Intel Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//*****************************************************************************

#pragma once

#include <memory>

#include "ngraph/op/util/binary_elementwise_arithmetic.hpp"

namespace ngraph
{
    namespace op
    {
        /// \brief Elementwise full arctan operation
        class Atan2 : public util::BinaryElementwiseArithmetic
        {
        public:
            NGRAPH_API
            static constexpr NodeTypeInfo type_info{"Atan2", 0};
            const NodeTypeInfo& get_type_info() const override { return type_info; }
            Atan2() = default;

            /// \brief atan2(y,x) is the angle from the origin to the point (x,y) (note reversed
            /// order).
            ///
            /// \param y
            /// \param x
            Atan2(const Output<Node>& y,
                  const Output<Node>& x,
                  const AutoBroadcastSpec& autob = AutoBroadcastSpec());
            std::shared_ptr<Node> copy_with_new_args(const NodeVector& new_args) const override;

        protected:
            virtual void generate_adjoints(autodiff::Adjoints& adjoints,
                                           const NodeVector& deltas) override;
        };
    }
}

==> ngraph-v0.28.0-rc.1.tar: ngraph-v0.28.0-rc.1/src/ngraph/op/atan2.hpp <==
//*****************************************************************************
// Copyright 2017-2020 Intel Corporation
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//*****************************************************************************

#pragma once

#include <memory>

#include "ngraph/op/util/binary_elementwise_arithmetic.hpp"

namespace ngraph
{
    namespace op
    {
        /// \brief Elementwise full arctan operation
        class NGRAPH_API Atan2 : public util::BinaryElementwiseArithmetic
        {
        public:
            static constexpr NodeTypeInfo type_info{"Atan2", 0};
            const NodeTypeInfo& get_type_info() const override { return type_info; }
            Atan2()
                : util::BinaryElementwiseArithmetic(AutoBroadcastSpec::NONE)
            {
            }

            /// \brief atan2(y,x) is the angle from the origin to the point (x,y) (note reversed
            /// order).
            ///
            /// \param y
            /// \param x
            Atan2(const Output<Node>& y,
                  const Output<Node>& x,
                  const AutoBroadcastSpec& autob = AutoBroadcastSpec());
            std::shared_ptr<Node> copy_with_new_args(const NodeVector& new_args) const override;

        protected:
            virtual void generate_adjoints(autodiff::Adjoints& adjoints,
                                           const OutputVector& deltas) override;
        };
    }
}
